#include <FastLED.h>
//
#define DATA_VU_RT_PIN 5      //This is the helmet's right side matrix
#define DATA_VU_LT_PIN 6      //This is the helmet's right side matrix
#define NUM_LEDS    12        // The LED frames are 7 LEDs in 8 groups/segments 
#define BRIGHTNESS  32        //Brightness level of leds adjustable and not to burn out the LEDS.
#define LED_TYPE    WS2812B   //Type of addressable LED strip I am using
#define COLOR_ORDER GRB       //Led type as manufactured.
//
// UV Meter Connections
int DO = 2; //Pin for Digital Output - DO
int AO = A0; // Pin for Analog Output - AO
int threshold1 = 10; //Set minimum threshold for LED lit
int threshold2 = 20; //Set minimum threshold for LED lit
int threshold3 = 30; //Set minimum threshold for LED lit
int threshold4 = 50; //Set minimum threshold for LED lit
int threshold5 = 70; //Set minimum threshold for LED lit
int threshold6 = 100; //Set minimum threshold for LED lit
int threshold7 = 130; //Set minimum threshold for LED lit
int threshold8 = 160; //Set minimum threshold for LED lit
int threshold9 = 190; //Set minimum threshold for LED lit
int sensorvalue = 0;
//
CRGB led_array[NUM_LEDS];
#define UPDATES_PER_SECOND 100
//..........................................
//
const uint8_t kMatrixWidth = 1;          // break up LED string into a matrix 7 leds in width x 8 groups(or rows) high.
const uint8_t kMatrixHeight = 12;        // Width x height = total number of leds in your string (here it is 7x8 = 56).
const bool    kMatrixSerpentineLayout = true;   // True if Leds are wired in a serpintine assembled pattern, false if led strip is laid out as a linear orientation.
//
// Calculates position on string based on coordinates.  This sets up the serpentine / zig zag to work.
uint16_t XY( uint8_t x, uint8_t y)
//                               XY(x,y) takes x and y coordinates and returns an LED index number,
//                               for use like this:  leds[ XY(x,y) ] == CRGB::Red;
//                               No error checking is performed on the ranges of x and y.
{
  uint16_t i;
//                               This function will return the right 'led index number' for
//                                a given set of X and Y coordinates on your matrix.
//
  if( kMatrixSerpentineLayout == false) {
    i = (y * kMatrixWidth) + x;
  }
  if( kMatrixSerpentineLayout == true) {
    if( y & 0x01) {
      // Odd rows run backwards
      uint8_t reverseX = (kMatrixWidth - 1) - x;
      i = (y * kMatrixWidth) + reverseX;
    } else {
      // Even rows run forwards
      i = (y * kMatrixWidth) + x;
    }
  }
    return i;
}
CRGBPalette16 currentPalette;  // Calling up the library for pallette to be assigned to "current pallette"
TBlendType    currentBlending;  // Calling up the library for method for blending colors
//
//............... SET UP......................................... 
void setup() {
    delay( 3000 ); // power-up safety delay
    Serial.begin(9600);    // Open Serial port to help trouble shoot when a button is being pressed.

    // Calling up FastLed code to assign the pin to the LED string being used, the size etc....
    
    FastLED.addLeds<LED_TYPE, DATA_VU_RT_PIN, COLOR_ORDER>(led_array, NUM_LEDS).setCorrection( TypicalLEDStrip );
    FastLED.addLeds<LED_TYPE, DATA_VU_LT_PIN, COLOR_ORDER>(led_array, NUM_LEDS).setCorrection( TypicalLEDStrip );
    FastLED.setBrightness(  BRIGHTNESS );
      currentPalette = RainbowColors_p;  //Calls up the rainbow pallette already canned in the library.
    currentBlending = LINEARBLEND;     //Calls up the blending method.
}
// ___________________SUBROUTINE ANIMATIONS START HERE _________________________
//
//
void clear()                      //  Clears the entire display to OFF of "black."
{
    for (int i = 0; i < NUM_LEDS; i++)
    {
        led_array[i] = CRGB::Black;
    }
    FastLED.show();
}
//
//.....................................
//..............................................
CRGB rainbow[9] = {CRGB::Red, CRGB::DarkMagenta, CRGB::Blue,
                   CRGB::DarkCyan, CRGB::DarkGreen, CRGB::Chartreuse,
                   CRGB::Yellow, CRGB::OrangeRed, CRGB::Red};

// ....................................
//
int cycleColor = 0;
//
//
//
//------------------------------------ LOOP PROGRAM BELOW ------------------------
void loop()
{
sensorvalue = analogRead(A0); //Read the analog value
Serial.print("Analog: ");
Serial.print(sensorvalue); //Print the analog value
Serial.print(" ");
Serial.print("Digital: ");
Serial.println(digitalRead(DO)); //Print the digital value
//
//
if (sensorvalue >= threshold1 && sensorvalue <= threshold2) //Compare analog value with threshold
{ 
    led_array[3] = CRGB::Red;
        led_array[2] = CRGB::Black;
            led_array[1] = CRGB::Black;
                led_array[0] = CRGB::Black;
                    //
    led_array[4] = CRGB::Red;
        led_array[5] = CRGB::Black;
            led_array[6] = CRGB::Black;
                led_array[7] = CRGB::Black;
                    //
    led_array[11] = CRGB::Red;
        led_array[10] = CRGB::Black;
            led_array[9] = CRGB::Black;
                led_array[8] = CRGB::Black;
   FastLED.show();
}
    if (sensorvalue > threshold2  && sensorvalue <= threshold3) //Compare analog value with threshold
{ 
    led_array[3] = CRGB::Red;
        led_array[2] = CRGB::OrangeRed;
            led_array[1] = CRGB::Black;
                led_array[0] = CRGB::Black;
                    //
    led_array[4] = CRGB::Red;
        led_array[5] = CRGB::OrangeRed;
            led_array[6] = CRGB::Black;
                led_array[7] = CRGB::Black;
                    //
    led_array[11] = CRGB::Red;
        led_array[10] = CRGB::OrangeRed;
            led_array[9] = CRGB::Black;
                led_array[8] = CRGB::Black;
   FastLED.show();
}
if (sensorvalue > threshold3  && sensorvalue <= threshold4) //Compare analog value with threshold
{ 
    led_array[3] = CRGB::Red;
        led_array[2] = CRGB::OrangeRed;
            led_array[1] = CRGB::Yellow;
                led_array[0] = CRGB::Black;
                    //
    led_array[4] = CRGB::Red;
        led_array[5] = CRGB::OrangeRed;
            led_array[6] = CRGB::Yellow;
                led_array[7] = CRGB::Black;
                    //
    led_array[11] = CRGB::Red;
        led_array[10] = CRGB::OrangeRed;
            led_array[9] = CRGB::Yellow;
                led_array[8] = CRGB::Black;
   FastLED.show();
}
if (sensorvalue > threshold4  && sensorvalue <= threshold5) //Compare analog value with threshold
{ 
    led_array[3] = CRGB::Red;
        led_array[2] = CRGB::OrangeRed;
            led_array[1] = CRGB::Yellow;
                led_array[0] = CRGB::Chartreuse;
                    //
    led_array[4] = CRGB::Red;
        led_array[5] = CRGB::OrangeRed;
            led_array[6] = CRGB::Yellow;
                led_array[7] = CRGB::Chartreuse;
                    //
    led_array[11] = CRGB::Red;
        led_array[10] = CRGB::OrangeRed;
            led_array[9] = CRGB::Yellow;
                led_array[8] = CRGB::Chartreuse;
   FastLED.show();
}
if (sensorvalue > threshold5 && sensorvalue <= threshold6) //Compare analog value with threshold
{ 
    led_array[3] = CRGB::OrangeRed;
        led_array[2] = CRGB::Yellow;
            led_array[1] = CRGB::Chartreuse;
                led_array[0] = CRGB::DarkGreen;
                    //
    led_array[4] = CRGB::OrangeRed;
        led_array[5] = CRGB::Yellow;
            led_array[6] = CRGB::Chartreuse;
                led_array[7] = CRGB::DarkGreen;
                    //
    led_array[11] = CRGB::OrangeRed;
        led_array[10] = CRGB::Yellow;
            led_array[9] = CRGB::Chartreuse;
                led_array[8] = CRGB::DarkGreen;
   FastLED.show();
}
if (sensorvalue > threshold6 && sensorvalue <= threshold7) //Compare analog value with threshold
{ 
    led_array[3] = CRGB::Yellow;
        led_array[2] = CRGB::Chartreuse;
            led_array[1] = CRGB::DarkGreen;
                led_array[0] = CRGB::DarkCyan;
                    //
    led_array[4] = CRGB::Yellow;
        led_array[5] = CRGB::Chartreuse;
            led_array[6] = CRGB::DarkGreen;
                led_array[7] = CRGB::DarkCyan;
                    //
    led_array[11] = CRGB::Yellow;
        led_array[10] = CRGB::Chartreuse;
            led_array[9] = CRGB::DarkGreen;
                led_array[8] = CRGB::DarkCyan;
   FastLED.show();
}
if (sensorvalue > threshold7 && sensorvalue <= threshold8) //Compare analog value with threshold
{ 
    led_array[3] = CRGB::Chartreuse;
        led_array[2] = CRGB::DarkGreen;
            led_array[1] = CRGB::DarkCyan;
                led_array[0] = CRGB::Blue;
                    //
    led_array[4] = CRGB::Chartreuse;
        led_array[5] = CRGB::DarkGreen;
            led_array[6] = CRGB::DarkCyan;
                led_array[7] = CRGB::Blue;
                    //
    led_array[11] = CRGB::Chartreuse;
        led_array[10] = CRGB::DarkGreen;
            led_array[9] = CRGB::DarkCyan;
                led_array[8] = CRGB::Blue;
   FastLED.show();
}
if (sensorvalue > threshold8 && sensorvalue < threshold9) //Compare analog value with threshold
{ 
    led_array[3] = CRGB::DarkGreen;
        led_array[2] = CRGB::DarkCyan;
            led_array[1] = CRGB::Blue;
                led_array[0] = CRGB::DarkMagenta;
                    //
    led_array[4] = CRGB::DarkGreen;
        led_array[5] = CRGB::DarkCyan;
            led_array[6] = CRGB::Blue;
                led_array[7] = CRGB::DarkMagenta;
                    //
    led_array[11] = CRGB::DarkGreen;
        led_array[10] = CRGB::DarkCyan;
            led_array[9] = CRGB::Blue;
                led_array[8] = CRGB::DarkMagenta;
   FastLED.show();
}
if (sensorvalue >= threshold9) //Compare analog value with threshold
{ 
    led_array[3] = CRGB::White;
        led_array[2] = CRGB::White;
            led_array[1] = CRGB::White;
                led_array[0] = CRGB::White;
                    //
    led_array[4] = CRGB::White;
        led_array[5] = CRGB::White;
            led_array[6] = CRGB::White;
                led_array[7] = CRGB::White;
                    //
    led_array[11] = CRGB::White;
        led_array[10] = CRGB::White;
            led_array[9] = CRGB::White;
                led_array[8] = CRGB::White;
   FastLED.show();
}

delay(40);
}
